package database

import (
	"time"

	"github.com/google/uuid"
)

type CloneCredentialType string

const (
	USER_PASS CloneCredentialType = "USER_PASS"
	SSH_KEY   CloneCredentialType = "SSH_KEY"
)

type CloneCredential struct {
	Id       uuid.UUID
	Name     string
	Type     CloneCredentialType
	Username string
	Secret   string
}

type Pipeline struct {
	Id              uuid.UUID
	Name            string
	Url             string
	PollInterval    int
	CloneCredential *uuid.UUID
}

type Secret struct {
	Id     uuid.UUID
	Name   string
	Secret string
}

type PipelineSecretMapping struct {
	Pipeline uuid.UUID
	Secret   uuid.UUID
}

type WebhookSender string

const (
	Gitea WebhookSender = "gitea"
)

type Webhook struct {
	Id         uuid.UUID
	ServerType WebhookSender
	Secret     string
	Pipeline   uuid.UUID
}

type Run struct {
	Id          uuid.UUID
	Pipeline    uuid.UUID
	InProgress  bool
	Result      *int64
	BuildOutput []byte
	Stdout      []byte
	Stderr      []byte
}

type CommandExecution struct {
	Id         uuid.UUID
	RunId      uuid.UUID
	Command    []string
	ReturnCode int
	Stdout     string
	Stderr     string
	StartTime  time.Time
	EndTime    time.Time
}

type Runner struct {
	Id    uuid.UUID
	Name  string
	Token string
}

type Cron struct {
	Id         uuid.UUID
	PipelineId uuid.UUID
	Cron       string
	Pattern    string
}
